# dist file #

```
# ----------------------------------------------------------------------
# jobfile backup.job for scheduling local dumps
#
# SYNTAX: 
# [variable] = [value]
#
# - variable must start in first column
# - char "=" must be surrounded by space
# - value - any string; no " needed
#
# ----------------------------------------------------------------------

lang = en_us

# ----------------------------------------------------------------------
# backup type; one of auto|inc
#   inc:   incremetal and full backups if started on cofigured times
#   auto:  automatic; =incermental backups; duplicity can start a full 
#          backup if the last one is older a given range
# ----------------------------------------------------------------------

# type = inc
type = auto

# ----------------------------------------------------------------------
# scheduling for full backup
# type = inc only
# for inc and full you can set
#   DOM:06,22        - days of month
#   DOW:Mon,Fri      - weekdays
#   WDM:WDM:1st Fri  - nth weekday in month
# ----------------------------------------------------------------------

# full = WDM:3rd Fri

# when to start a full backup?
#   regex that must match a time HH:MM somewhen
#   This will start it if backup ist started between 23:00:00 and 23:09:59
# start-time-full = 23:0.

# ----------------------------------------------------------------------
# full backups for type = auto AND when using duplicity
# ----------------------------------------------------------------------
# auto = <time> i.e. 1M 
# auto = 1M


# ----------------------------------------------------------------------
# local dumps; each service has its own subdir there
# this entry is mapped to BACKUP_TARGETDIR in "localdump.sh"
# ----------------------------------------------------------------------
dir-localdumps = /var/localdumps/backup
keep-days = 7

# archive databases (to keep deleted schemes or databases that 
# are not backupped anymore; couchdb2 feature)
dir-dbarchive = /var/localdumps/archive

# ----------------------------------------------------------------------

```

# Description #

## auto ##

Define when to make full backups for `type = auto`. It starts incremental backups
only as long the last full backup is not older than the given range.

It is used for Duplicity only and forces the parameter `--full-if-older-than [value]`.

Values are a number followed by a single letter for the time:
s, m, h, D, W, M, or Y (indicating seconds, minutes, hours, days, weeks, months, or years respectively)

`auto = 1M`

## dir-dbarchive ##

Target dir for database archives (to keep deleted schemes or databases that are not backupped anymore; couchdb2 feature)

`dir-dbarchive = /var/localdumps/archive`

## dir-localdumps ##

Target dir for database backups of all types. 
Below that directory a subdir for the database type will be created (i.e. mysql or pgsql).

`dir-localdumps = /var/localdumps/backup`

see also **keep-days**

## keep-days ##

How many days to keep database dumps locally in `dir-localdumps = ...`

`keep-days = 7`

see also **dir-localdumps**

## full ##

Scheduling days for full backup
You can set

* day of month: DOM
* weekday: DOW
* nth weekday in a month: WDM

It is followes by a `:` and a single value - or multiple values delimited by `,`.

* Day of month is always a 2 digit value (01..31).
* Keywords for weekdays are Mon, Tue, Wed, Thu, Fri, Sat, Sun.
* Valid numbers of day are 1st, 2nd, 3rd, 4th, 5th followes by space and a weekday

Examples:

* DOM:06,22        - days of month
* DOW:Mon,Fri      - weekdays
* WDM:1st Fri      - nth weekday in month

`full = WDM:3rd Fri`

See also: **start-time-full**

## lang ##

Language of the shell. Do not change to keep documented keywords for date and time.

## start-time-full ##

Time when to start an incrmental backup. This value will be handled
if a day matches **full** only.

The value of start-time-full is a regex then must match a time HH:MM somewhen
to start a full backup.

This will start it if backup ist started between 23:00:00 and 23:09:59:

`start-time-full= 23:0.`

see also **full**

## type ##

Type of backup. The value is one of auto|inc

* inc:   incremetal and full backups if started on cofigured times
* auto:  automatic; =incermental backups; duplicity can start a full backup if the last one is older a given range

This setting depends on the possibilities of the used backup tool.

Restic:

* set to "auto" only

Duplicity:

Duplicity supports 2 modes.

* "inc" - make full and incremental backups defined times. You need more values:
  * full = WDM:3rd Fri
  * start-time-full = 23:0.

* "auto" - starts incremental backups as long last full backup is not older value in
  * auto = 1M

`type = auto`

see also **bin**

## Example: Restic ##

```text
lang = en_us
type = auto


# ----------------------------------------------------------------------
# local dumps; each service has its own subdir there
# this entry is mapped to BACKUP_TARGETDIR in "localdump.sh"
# ----------------------------------------------------------------------
dir-localdumps = /var/localdumps/backup
keep-days = 7

# archive databases (to keep deleted schemes or databases that 
# are not backupped anymore; couchdb2 feature)
dir-dbarchive = /var/localdumps/archive

```

## Example: Duplicity ##

### Full backups on a specified time ###

This can be used on servers where you want to define when the full
backup must be started.

```text
lang = en_us
type = inc

# ----------------------------------------------------------------------
# scheduling for full backup
# type = inc only
# for inc and full you can set
#   DOM:06,22        - days of month
#   DOW:Mon,Fri      - weekdays
#   WDM:WDM:1st Fri  - nth weekday in month
# ----------------------------------------------------------------------

full = WDM:3rd Fri

# when to start a full backup?
#   regex that must match a time HH:MM somewhen
#   This will start it if backup ist started between 23:00:00 and 23:09:59
start-time-full = 23:0.


# ----------------------------------------------------------------------
# local dumps; each service has its own subdir there
# this entry is mapped to BACKUP_TARGETDIR in "localdump.sh"
# ----------------------------------------------------------------------
dir-localdumps = /var/localdumps/backup
keep-days = 7

# archive databases (to keep deleted schemes or databases that 
# are not backupped anymore; couchdb2 feature)
dir-dbarchive = /var/localdumps/archive

```

### Full backups after a month ###

This can be used on client backups. A full backup automatically starts
if the last backup is older a given time.

```text
lang = en_us
type = auto

# ----------------------------------------------------------------------
# full backups for type = auto AND when using duplicity
# ----------------------------------------------------------------------
# auto = <time> i.e. 1M 
auto = 1M


# ----------------------------------------------------------------------
# local dumps; each service has its own subdir there
# this entry is mapped to BACKUP_TARGETDIR in "localdump.sh"
# ----------------------------------------------------------------------
dir-localdumps = /var/localdumps/backup
keep-days = 7

# archive databases (to keep deleted schemes or databases that 
# are not backupped anymore; couchdb2 feature)
dir-dbarchive = /var/localdumps/archive
```